# Target Snowflake

Placeholder for `target-snowflake`

## Snowflake Connector

[Docs](https://docs.snowflake.net/manuals/user-guide/python-connector.html)

## TODO

Implement.

## Sponsorship

Target Snowflake is sponsored by Data Mill (Data Mill Services, LLC) [datamill.co](https://datamill.co/).

Data Mill helps organizations utilize modern data infrastructure and data science to power analytics, products, and services.

---

Copyright Data Mill Services, LLC 2018
